#!/usr/bin/env python
"""
Responsible for loading all of the environmental variables.
"""
__author__ = "Lloyd McCarthy"
__license__ = "MIT"

import os
from os import environ as env
from dotenv import find_dotenv, load_dotenv
from cidc_utils.caching import CredentialCache

ENV_FILE = find_dotenv()
if ENV_FILE:
    with open(ENV_FILE) as fin:
      lines = fin.readlines()
      for line in lines:
        k, v = line.split("=")
        env[k] = v.strip()

DOMAIN = env.get('DOMAIN')
AUDIENCE = env.get('AUDIENCE')
CLIENT_ID = env.get('CLIENT_ID')
REDIRECT_URI = env.get('REDIRECT_URI')
SCOPE = env.get('SCOPE')
EVE_URL = env.get('EVE_URL')
IDP = env.get('IDP')
USER_CACHE = CredentialCache(100, 600)
FILE_EXTENSION_DICT = {
    "fa": "FASTQ",
    "fa.gz": "FASTQ",
    "fq.gz": "FASTQ"
}

BANNER = '''
###################██████╗██╗██████╗##██████╗#########################
##################██╔════╝██║██╔══██╗██╔════╝#########################
##################██║#####██║██║##██║██║##############################
##################██║#####██║██║##██║██║##############################
##################╚██████╗██║██████╔╝╚██████╗#########################
###################╚═════╝╚═╝╚═════╝##╚═════╝#########################
######################################################################
###██████╗#██████╗#███╗###███╗███╗###███╗#█████╗#███╗###██╗██████╗####
##██╔════╝██╔═══██╗████╗#████║████╗#████║██╔══██╗████╗##██║██╔══██╗###
##██║#####██║###██║██╔████╔██║██╔████╔██║███████║██╔██╗#██║██║##██║###
##██║#####██║###██║██║╚██╔╝██║██║╚██╔╝██║██╔══██║██║╚██╗██║██║##██║###
##╚██████╗╚██████╔╝██║#╚═╝#██║██║#╚═╝#██║██║##██║██║#╚████║██████╔╝###
###╚═════╝#╚═════╝#╚═╝#####╚═╝╚═╝#####╚═╝╚═╝##╚═╝╚═╝##╚═══╝╚═════╝####
######################################################################
#██╗#####██╗███╗###██╗███████╗####████████╗#██████╗##██████╗#██╗######
#██║#####██║████╗##██║██╔════╝####╚══██╔══╝██╔═══██╗██╔═══██╗██║######
#██║#####██║██╔██╗#██║█████╗#########██║###██║###██║██║###██║██║######
#██║#####██║██║╚██╗██║██╔══╝#########██║###██║###██║██║###██║██║######
#███████╗██║██║#╚████║███████╗#######██║###╚██████╔╝╚██████╔╝███████╗#
#╚══════╝╚═╝╚═╝##╚═══╝╚══════╝#######╚═╝####╚═════╝##╚═════╝#╚══════╝#
######################################################################'''
